@@ -1,41 +1,45 @@
 use utf8;
 package WebService::KvKAPI::Roles::OpenAPI;
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 # ABSTRACT: WebService::KvkAPI::Roles::OpenAPI package needs a propper abstract
 
 use v5.26;
 use Object::Pad;
 
 role WebService::KvKAPI::Roles::OpenAPI;
-use Carp qw(croak);
+use Carp qw(croak cluck);
 use OpenAPI::Client;
 use Try::Tiny;
+use Data::Dumper;
 
-field $api_host :accessor :param = undef;
-field $api_key  :param = undef;
-field $spoof    :param = 0;
+field $api_host :accessor :param = 'api.kvk.nl';
+field $api_path :accessor :param = '/api';
+field $spoof    :accessor :param = 0;
 field $client   :accessor;
+field $is_v2    :accessor :param = 0;
+
+field $api_key  :param = undef;
 
 ADJUST {
 
-    my $base_uri = 'https://api.kvk.nl/api';
-
     if ($spoof) {
-        $base_uri = 'https://api.kvk.nl/test/api';
-        # publicly known API key
+        $api_path = '/test' . $self->api_path;
         $api_key = 'l7xx1f2691f2520d487b902f4e0b57a0b197';
     }
 
-    # work around api-key not being present with the api_call method
     if (!defined $api_key) {
         croak("Please supply an API-key with construction");
     }
 
     my $definition = sprintf('data://%s/kvkapi.yml', ref $self);
-    $client = OpenAPI::Client->new($definition, base_url => $base_uri);
-    if ($self->has_api_host) {
-        $client->base_url->host($self->api_host);
-    }
+    $client = OpenAPI::Client->new($definition);
+
+    my $host = Mojo::URL->new();
+    $host->scheme('https');
+    $host->host($self->api_host);
+    $host->path($self->api_path);
+
+    $client->base_url($host);
 
     $client->ua->on(start => sub ($ua, $tx) {
       $tx->req->headers->header('apikey' => $api_key);
@@ -53,6 +57,10 @@ method has_api_host {
 method api_call {
     my ($operation, %query) = @_;
 
+    if ($is_v2) {
+        $client->base_url->path($self->api_path . '/v2');
+    }
+
     my $tx = try {
         $client->call(
             $operation => \%query,
@@ -78,6 +86,10 @@ method api_call {
     return $tx->res->json;
 }
 
+method deprecated_item($old, $new, $api) {
+    cluck "Deprecated item found in $api: $old has been renamed to $new";
+}
+
 1;
 
 __END__
@@ -92,7 +104,7 @@ WebService::KvKAPI::Roles::OpenAPI - WebService::KvkAPI::Roles::OpenAPI package
 
 =head1 VERSION
 
-version 0.105
+version 0.106
 
 =head1 SYNOPSIS
 
